/* Copyright (c) 2012, 2013, 2014 BlackBerry Limited.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import bb.cascades 1.3
import bb.cascades.pickers 1.0



// When the quote is in edit mode, it is possible to change the name.
// This control presents the input fields for editing the name of the entry.
Container {
    id: editName
    property alias firstName: firstNameField.text
    property alias lastName: lastNameField.text
    property alias aobrazek: obrazekField.imageSource
    property alias azneni: zneniField.text
    property alias aaktivni: pomAktivni.text
    property alias ajednotky: pomJednotky.text
    property alias apocet: pocetField.text
    signal enableSave(bool enable)
    
    property string eMessage: qsTr("Wrong number") + Retranslate.onLanguageChanged;
    
    layout: StackLayout {
        orientation: LayoutOrientation.TopToBottom
    
    }
    property real margins: ui.du(3)
    
    
    topPadding: margins
    leftPadding: margins
    rightPadding: margins
    bottomPadding: margins
    
    attachedObjects: [
 
                
        FilePicker {
            id:obrazekPicker
            type : FileType.Picture
            title : "Select Picture"
            //directories : ["file://"+"app/native/assets"]
            onFileSelected : {
                obrazekField.imageSource = "file://" + selectedFiles[0];
            }
            defaultType: FileType.Other
            viewMode: FilePickerViewMode.Default
        },
        ContactPicker {
            id:vyberKontakt
            
            onContactSelected: 
            {                                             
                ddCislo.removeAll();
                for (var i = 0; i < QuotesApp.telCislo(contactId).length; i++) {
                    var newOption = emptyOption.createObject()
                    newOption.text = QuotesApp.telCislo(contactId)[i];
                    ddCislo.add(newOption);
                }
                if ((QuotesApp.telCislo(contactId).length > 0) && (lastNameField.text == QuotesApp.telCislo(contactId)[0]))
                {ddCislo.selectedIndex = 0};
                ddCislo.visible = true;
            }
        },
        ComponentDefinition {
            id: emptyOption
            Option {}
        }
    ]
    
    onVisibleChanged: {
        if (visible) {
            // When this component becomes visible we request focus to show the
            // virtual keyboard (if available) and to hint that this field is required.
            
                
            if (aaktivni == "asset:///images/Cell-Green.png") {aktivniField.checked = true}
            else {aktivniField.checked = false};
            if (ajednotky == qsTr("minutes")) {jednotkyField.selectedIndex = 0}
            if (ajednotky == qsTr("hours")) {jednotkyField.selectedIndex = 1}
            if (ajednotky == qsTr("days")) {jednotkyField.selectedIndex = 2}
            lastNameField.requestFocus();
        }
    }
    horizontalAlignment: HorizontalAlignment.Center
    ScrollView {
        Container {
            id: cnMain
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Center
            layout: StackLayout {
                orientation: LayoutOrientation.TopToBottom
            
            }
            Label {
                text: qsTr("Telephone number") + Retranslate.onLanguageChanged
                textStyle.fontWeight: FontWeight.Bold
            }
            // Text field for last name
            TextField {
                id: lastNameField
                hintText: qsTr("Telephone number") + Retranslate.onLanguageChanged
                
                onTextChanging: {
                    // Since the last name is the primary key for the entry. We will disable buttons and text areas 
                    // until the last name length is not zero.
                    if (text.length > 0) {
                        editName.enableSave(true);
                        firstNameField.enabled = true;
                    } else {
                        editName.enableSave(false);
                        firstNameField.enabled = false;
                    }
                }
                onTouch: {
                    vyberKontakt.open();
                
                }
            }// TextField
            //pomocny combobox
            DropDown {
                id: ddCislo
                visible: false
                onSelectedIndexChanged: {
                    lastNameField.text = ddCislo.selectedOption.text
                    ddCislo.visible = false;
                }
            
            }
        Divider {
        
        }
        Container {
            verticalAlignment: VerticalAlignment.Center
            horizontalAlignment: HorizontalAlignment.Center
            layout: StackLayout {
                orientation: LayoutOrientation.TopToBottom
            
            }
            Label {
                text: qsTr("SMS description") + Retranslate.onLanguageChanged
                textStyle.fontWeight: FontWeight.Bold
            
            }
            // Text field for first name
            TextField {
                id: firstNameField
                hintText: qsTr("SMS description") + Retranslate.onLanguageChanged
            
            }
            
        }
        
        
        
        Label {
            text: qsTr("SMS body") + Retranslate.onLanguageChanged
            textStyle.fontWeight: FontWeight.Bold
        }
        // Text field for last name
        TextArea {
            id: zneniField
            hintText: qsTr("SMS body") + Retranslate.onLanguageChanged
            onTextChanging: {
                lbCharCount.text = zneniField.text.length;
            }
        }
        Label {
            id: lbCharCount
            textStyle.color: Color.DarkBlue
            text: "0"
            textStyle.fontSize: FontSize.XSmall
        
        }
        Divider {
        
        } // TextField
        Label {
            text: qsTr("SMS icon") + Retranslate.onLanguageChanged
            textStyle.fontWeight: FontWeight.Bold
        }
        ImageView {
            id: obrazekField
            onTouch: {
                obrazekPicker.directories = ["/listimages/"]
                console.log(obrazekPicker.directories[0])
                obrazekPicker.open()
            }
            preferredWidth: 100.0
            preferredHeight: 100.0
            accessibility.description: ""
            imageSource: "asset:///listimages/ScheduledPays.png"
            accessibilityMode: A11yMode.Default
        
    }
    Divider {
    
    }
    Label {
        text: qsTr("SMS automation") + Retranslate.onLanguageChanged
        textStyle.fontWeight: FontWeight.Bold
    }
    Container {
        layout: StackLayout {
            orientation: LayoutOrientation.TopToBottom
        
        }
        Label {
            text: qsTr("Send this SMS every") + Retranslate.onLanguageChanged   
        }
        TextField {
            id: pocetField
            inputMode: TextFieldInputMode.NumbersAndPunctuation
            validator: Validator {
                mode: ValidationMode.FocusLost
                errorMessage: editName.eMessage
                onValidate: {
                    if (pocetField.text == "") {pocetField.text = "1"};
                    if (QuotesApp.StringToInt(pocetField.text)) {state = ValidationState.Valid} 
                    else {state = ValidationState.Invalid; pocetField.requestFocus()};
                }
                delay: 1
            }
        }
        DropDown {
            id: jednotkyField
            title: qsTr("Interval") + Retranslate.onLanguageChanged
                    onSelectedIndexChanged: {
                        pomJednotky.text = jednotkyField.selectedValue
                    }

            Option {
                text:qsTr("minutes") + Retranslate.onLanguageChanged
                value:qsTr("minutes") + Retranslate.onLanguageChanged 
            }
            Option {
                text:qsTr("hours") + Retranslate.onLanguageChanged
                value:qsTr("hours") + Retranslate.onLanguageChanged 
            }
            Option {
                text:qsTr("days") + Retranslate.onLanguageChanged
                value:qsTr("days") + Retranslate.onLanguageChanged 
            }
        
        }
        TextField {
            id: pomJednotky
                    visible: false

                }
        Container {
            verticalAlignment: VerticalAlignment.Top
            layout: DockLayout {
            
            }
            horizontalAlignment: HorizontalAlignment.Fill
            Label {
                text: qsTr("Active") + Retranslate.onLanguageChanged
                verticalAlignment: VerticalAlignment.Top
            
            }
            ToggleButton {
                id: aktivniField
                verticalAlignment: VerticalAlignment.Top
                horizontalAlignment: HorizontalAlignment.Right
                        onCheckedChanged: {
                            if (aktivniField.checked == true){pomAktivni.text = "asset:///images/Cell-Green.png"}
                            else {pomAktivni.text = "asset:///images/Cell-Red.png"};
                            
                        }

                    }
            Label {
                        id: pomAktivni
                        visible: false

                    }
        
        }
        
    }

}

}
    
}
