/* Copyright (c) 2012, 2013, 2014 BlackBerry Limited.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import bb.cascades 1.3
import bb.system 1.0

Page {
    id: quotePage
    
    // Data property, this is updated when navigation occurs, has three entries.
    property variant quoteData: {'cislo': "John", 'znenisms':"Doe", 'popis':"Bla bla bla bla blaaa.", 'obrazek':"asset:///listimages/ScheduledPays.png", 'aktivni':" ", 'jednotky':" ", 'pocet':0}
    
    // Signals for handling data updates triggered from the Quote Page.
    signal deleteQuote();
    signal updateQuote(string firstName, string lastName, string quote, string obrazek, string aktivni, string jednotky, int pocet);
    signal back();
        
    titleBar: TitleBar {
        title: qsTr("Edit") + Retranslate.onLanguageChanged
        visibility: quoteBubble.editMode ? ChromeVisibility.Visible : ChromeVisibility.Hidden; 
        acceptAction: ActionItem {
            title: qsTr("Save") + Retranslate.onLanguageChanged
        	enabled: quoteBubble.enableSave
            onTriggered: {
                quoteBubble.editMode = false;
                quotePage.updateQuote(quoteBubble.pendingFirstName, quoteBubble.pendingLastName, quoteBubble.pendingZneni, quoteBubble.pendingObrazek, quoteBubble.pendingAktivni, quoteBubble.pendingJednotky, quoteBubble.pendingPocet);
            }
        }

        dismissAction: ActionItem {
            title: qsTr("Cancel") + Retranslate.onLanguageChanged
            onTriggered: {
                quoteBubble.editMode = false;
                quoteBubble.quoteText = quotePage.quoteData["quote"];
            }
        }
    }
    
    Container {
        horizontalAlignment: HorizontalAlignment.Center

        QuoteBubble {
            id: quoteBubble
            // Since the data presented in the Quote bubble is connected to the list of quotes
            // and may change (on for example deletion), some of the properties of the QuoteBuble are set in the 
            // onQuoteDataChanged signal handler below.

			horizontalAlignment: HorizontalAlignment.Center
            
        } // QuoteBubble
    } // Container

    shortcuts: [
        SystemShortcut {
            // The edit  short cut puts the Page in edit mode.
            type: SystemShortcuts.Edit
            onTriggered: {
                quoteBubble.editMode = true;
            }
        }
    ]

    paneProperties: NavigationPaneProperties {
        backButton: ActionItem {
            title: qsTr("Messages") + Retranslate.onLanguageChanged
            onTriggered: {
                quoteBubble.editMode = false;
                quotePage.back();
            }
        }
    }
    
    actions: [
        ActionItem {            
            title: qsTr("Edit") + Retranslate.onLanguageChanged
            imageSource: "asset:///images/Edit.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            enabled: !quoteBubble.editMode

            onTriggered: {
                quoteBubble.editMode = true
            }
        },
        ActionItem {            
            title: qsTr("Send") + Retranslate.onLanguageChanged
            imageSource: "asset:///images/ic_textmessage_dk.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            //enabled: !quoteBubble.editMode
            
            onTriggered: {
                if (quoteBubble.lastName.length<2) 
                {QuotesApp.showSuccessMessage(qsTr("Phone number is too short") + Retranslate.onLanguageChanged);
                 return }
                senddialog.show();
                
                
            }
            attachedObjects: [
                SystemDialog {
                    id: senddialog
                    title: qsTr("Confirmation")
                    body: qsTr("SMS text: ")+"\n" +quoteBubble.quoteText+"\n" +qsTr(" will be sent to number ")+"\n" +quoteBubble.lastName+ (".")
                    onFinished: {
                        if (senddialog.result == SystemUiResult.ConfirmButtonSelection) 
                        {QuotesApp.sendSMS(quoteBubble.quoteText, quoteBubble.lastName);
                            QuotesApp.showSuccessMessage(qsTr("SMS has been queued for sending") + Retranslate.onLanguageChanged);}
                                                    
                    }
                }
            ]
        },
        DeleteActionItem {
            objectName: "DeleteAction"
            
            onTriggered: {
                quotePage.deleteQuote();
                quoteBubble.editMode = false
            }
        }
    ]
    
    onQuoteDataChanged: {
        // If the first name is not defined set it to an empty string
        quoteBubble.lastName =  (quotePage.quoteData["cislo"] == undefined) ? "" : quotePage.quoteData["cislo"]
        quoteBubble.firstName = quotePage.quoteData["popis"]
        quoteBubble.quoteText = quotePage.quoteData["znenisms"]
        quoteBubble.obrazek = quotePage.quoteData["obrazek"]
        quoteBubble.aktivni = quotePage.quoteData["aktivni"]
        quoteBubble.jednotky = quotePage.quoteData["jednotky"]
        quoteBubble.pocet = quotePage.quoteData["pocet"]
    }
    
    
    
}// Quote Page
