/* Copyright (c) 2012, 2013, 2014 BlackBerry Limited.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import bb.cascades 1.3
import bb.cascades.pickers 1.0

// The Edit Screen is where the text areas for editing and completing information for a new
// record is added together with two buttons for add/edit and cancel.
Sheet {
    id: addSheet
    signal addNewRecord(string firstName, string lastName, string quote, string obrazek, string aktivni, string jednotky, int pocet)
    property string aktivnistring;
    
    Page {
        id: addPage
        property string eMessage: qsTr("Wrong number") + Retranslate.onLanguageChanged; 
        titleBar: TitleBar {
            id: addBar
            title: qsTr("Add") + Retranslate.onLanguageChanged
            visibility: ChromeVisibility.Visible
            
            dismissAction: ActionItem {
                title: qsTr("Cancel") + Retranslate.onLanguageChanged
                onTriggered: {
                    addSheet.close()
                }
            }
            
            acceptAction: ActionItem {
                title: qsTr("Save") + Retranslate.onLanguageChanged
                enabled: false
                onTriggered: {
                    if (aktivniField.checked == true){aktivnistring = "asset:///images/Cell-Green.png"}
                    else {aktivnistring = "asset:///images/Cell-Red.png"}
                    addNewRecord(firstNameField.text, lastNameField.text, quoteField.text, obrazekField.imageSource, aktivnistring, 
                        jednotkyField.selectedValue, pocetField.text);
                    addSheet.close()
                }
            }
        }
        ScrollView {
            Container {
                id: editPane
                property real margins: ui.du(3)
                
                
                topPadding: margins
                leftPadding: margins
                rightPadding: margins
                bottomPadding: margins
                
                layout: DockLayout {
                }
                
                Container {
                    layout: StackLayout {
                    }
                    
                    Container {
                        
                        layout: StackLayout {
                            orientation: LayoutOrientation.TopToBottom
                        }
                        
                        
                        // Text field for the last name
                        TextField {
                            id: lastNameField
                            hintText: qsTr("Tel.number - type or click") + Retranslate.onLanguageChanged
                            
                            onTextChanging: {
                                
                                // A last name has to be entered disable buttons and text areas as long as the length is zero.
                                if (text.length > 0) {
                                    addPage.titleBar.acceptAction.enabled = true;
                                    quoteField.enabled = true;
                                    firstNameField.enabled = true;
                                } else {
                                    addPage.titleBar.acceptAction.enabled = false;
                                    quoteField.enabled = false;
                                    firstNameField.enabled = false;
                                }
                            
                            }
                            onTouch: {
                                vyberKontakt.open();
                            
                            }
                        }
                        //Last name text field
                        //pomocny combobox
                        DropDown {
                            id: ddCislo
                            visible: false
                            onSelectedIndexChanged: {
                                lastNameField.text = ddCislo.selectedOption.text
                                ddCislo.visible = false;
                            }
                        
                        }
                        // Text field for the first name
                        TextField {
                            id: firstNameField
                            hintText: qsTr("SMS description") + Retranslate.onLanguageChanged
                            enabled: false
                        }
                        attachedObjects: [
                            ComponentDefinition {
                                id: emptyOption
                                Option {}
                            }
                        ]
                    } // Name text Container
                    // The quote text area.
                    TextArea {
                        id: quoteField
                        hintText: qsTr("SMS body") + Retranslate.onLanguageChanged
                        bottomMargin: editPane.margins
                        enabled: false
                        //maxHeight: ui.du(45)
                        horizontalAlignment: HorizontalAlignment.Fill
                        onTextChanging: {
                            lbCharCount.text = quoteField.text.length;
                        }

                    }
                    Label {
                        id: lbCharCount
                        textStyle.color: Color.DarkBlue
                        text: "0"
                        textStyle.fontSize: FontSize.XSmall

                    }
                    Divider {
                        
                    }
                    Label {
                        text: qsTr("SMS icon") + Retranslate.onLanguageChanged    
                    }
                    ImageView {
                        id: obrazekField
                        onTouch: {
                            obrazekPicker.directories = ["/listimages/"]
                            obrazekPicker.open()
                        }
                        preferredWidth: 100.0
                        preferredHeight: 100.0
                        accessibility.description: ""
                        imageSource: "asset:///listimages/ScheduledPays.png"
                        accessibilityMode: A11yMode.Default
                    
                    }
                    Divider {

                    }
                    Label {
                        text: qsTr("SMS automation") + Retranslate.onLanguageChanged
                        textStyle.fontWeight: FontWeight.Bold
                    }
                    Container {
                        layout: StackLayout {
                            orientation: LayoutOrientation.TopToBottom

                        }
                        Label {
                            text: qsTr("Send this SMS every") + Retranslate.onLanguageChanged   
                        }
                        TextField {
                            id: pocetField
                            inputMode: TextFieldInputMode.NumbersAndPunctuation
                            validator: Validator {
                                mode: ValidationMode.FocusLost
                                errorMessage: addPage.eMessage
                                onValidate: {
                                    if (pocetField.text == "") {pocetField.text = "1"};
                                    if (QuotesApp.StringToInt(pocetField.text)) {state = ValidationState.Valid} 
                                    else {state = ValidationState.Invalid; pocetField.requestFocus()};
                                }
                                delay: 1
                            }
                        }
                        DropDown {
                            id: jednotkyField
                            selectedIndex: 0
                            title: qsTr("Interval") + Retranslate.onLanguageChanged
                            
                            Option {
                                text:qsTr("minutes") + Retranslate.onLanguageChanged
                                value:qsTr("minutes") + Retranslate.onLanguageChanged 
                            }
                            Option {
                                text:qsTr("hours") + Retranslate.onLanguageChanged
                                value:qsTr("hours") + Retranslate.onLanguageChanged 
                            }
                            Option {
                                text:qsTr("days") + Retranslate.onLanguageChanged
                                value:qsTr("days") + Retranslate.onLanguageChanged 
                            }
                        
                        }
                        Container {
                            verticalAlignment: VerticalAlignment.Top
                            layout: DockLayout {
                            
                            }
                            horizontalAlignment: HorizontalAlignment.Fill
                            Label {
                                text: qsTr("Active") + Retranslate.onLanguageChanged
                                verticalAlignment: VerticalAlignment.Top
                            
                            }
                            ToggleButton {
                                id: aktivniField
                                verticalAlignment: VerticalAlignment.Top
                                horizontalAlignment: HorizontalAlignment.Right
                            
                            }
                        
                        }
                    }
                    
                    attachedObjects: [
                        FilePicker {
                            id:obrazekPicker
                            type : FileType.Picture
                            title : "Select Picture"
                            //directories : ["file://"+"app/native/assets"]
                            onFileSelected : {
                                obrazekField.imageSource = "file://" + selectedFiles[0];
                                console.log(obrazekField.imageSource)                        
                            }
                            defaultType: FileType.Other
                            viewMode: FilePickerViewMode.Default
                        },
                        ContactPicker {
                            id:vyberKontakt
                            
                            onContactSelected: 
                            {                                             
                                ddCislo.removeAll();
                                for (var i = 0; i < QuotesApp.telCislo(contactId).length; i++) {
                                    var newOption = emptyOption.createObject()
                                    newOption.text = QuotesApp.telCislo(contactId)[i];
                                    ddCislo.add(newOption);
                                }
                                if (QuotesApp.telCislo(contactId).length > 0)
                                {ddCislo.selectedIndex = 0};
                                ddCislo.visible = true;
                            }
                        }
                    
                    
                    ]
                    
                    

                } //Total text Container (name text + quote text)
            
            
            
            } // Content Container
        } // TitleBar
        
        
    }
    
    onOpened: {
        // Focus can not be requested until the Sheet is part of the UI-tree, so we
        // wait until it has been shown and request focus for the last name field
        lastNameField.requestFocus();
    }
}
