/* Copyright (c) 2012, 2013, 2014 BlackBerry Limited.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import bb.cascades 1.3
import bb.data 1.0
import com.quotes.data 1.0
import bb.system 1.0
import qt 1.0


// The Page Containing the list of quotes. Data is loaded from SQL using the CustomSqlDataSource
// and puts into a GroupModel (QuotesModel.qml), which populates the list.
Page {
    id: quoteListPage

    // State variable used to make sure that the onItemAdded signals are only considered
    // after showing the add sheet the first time (to avoid signals appearing at start up).
    property bool addShown: false
    property variant selectedData
    property variant allData

	// We store the add sheet in a variable while its shown so we can destroy it once it is closed.
    property Sheet addSheet
    property Sheet settingsSheet
    property int celkovyCas
    property int recMS

    // Custom signals used to communicate navigation
    signal showQuotesPage()
    signal listEmpty()
    titleBar: TitleBar {
        title: "SMS Launcher Pro"
        appearance: TitleBarAppearance.Branded
        
    } 
    Container {
        ListView {
            id: quotesList
            layout: StackListLayout {
                headerMode: ListHeaderMode.Sticky
            }

            // The data model used defined in the attachedObjects for the list.
            dataModel: quotesModel

            // There are two types of item; header for alphabetic groups and standard items
            // showing the person name.
            listItemComponents: [
                ListItemComponent {
                    type: "item"
                    Container {
                        layout: StackLayout {
                            orientation: LayoutOrientation.TopToBottom

                        }

                        Container {
                            layout: GridLayout {
                                //orientation: LayoutOrientation.LeftToRight
                                columnCount: 3

                            }

                            horizontalAlignment: HorizontalAlignment.Fill
                            verticalAlignment: VerticalAlignment.Center
                            leftPadding: 20.0
                            ImageView {
                                imageSource: ListItemData.obrazek
                                maxWidth: 200.0
                                maxHeight: 200.0
                            }
                            Label {
                                
                                text: ListItemData.popis
                                horizontalAlignment: HorizontalAlignment.Left
                                textStyle.fontWeight: FontWeight.Bold

                            }
                            Container {
                                horizontalAlignment: HorizontalAlignment.Right

                                background: Color.create("#ffe99b00")
                                verticalAlignment: VerticalAlignment.Top
                                Label {
                                    
                                    text: ListItemData.cislo
                                    horizontalAlignment: HorizontalAlignment.Right
                                    textStyle.color: Color.White
                                    

                                }
                            }
                        
                        }
                        
                        Container {
                            visible: (ListItemData.pocet != 0)
                            layout: StackLayout {
                                orientation: LayoutOrientation.RightToLeft
                            }

                            horizontalAlignment: HorizontalAlignment.Fill
                            rightPadding: 20.0
                            ImageView {
                                imageSource: ListItemData.aktivni
                                horizontalAlignment: HorizontalAlignment.Right
                            }
                            Label {
                                
                                text: ListItemData.jednotky
                                
                                textStyle.fontStyle: FontStyle.Italic
                                horizontalAlignment: HorizontalAlignment.Right

                            }
                            Label {

                                text: qsTr("Automation: ") + ListItemData.pocet
                                textStyle.fontStyle: FontStyle.Italic
                                horizontalAlignment: HorizontalAlignment.Right

                            }
                            
                            
                        }
                        Divider {

                        }

                    }
                    

                },
                ListItemComponent {
                    type: "header"
                    Header {
                        title: ListItemData
                        subtitle: qsTr("SMS description starting with: ")
                        horizontalAlignment: HorizontalAlignment.Left
                        accessibilityMode: A11yMode.Collapsed
                    }
                }

            ]
            contextActions: [
                ActionSet {

                    actions: [
                        ActionItem {
                            title: qsTr("Edit") + Retranslate.onLanguageChanged
                            onTriggered: {
                                if (quoteListPage.selectedData != undefined) {
                                    quoteListPage.showQuotesPage();
                                }
                            }
                        },
                        DeleteActionItem {
                            objectName: "DeleteAction"

                            onTriggered: {
                                if (quoteListPage.selectedData != undefined) {
                                    deleteSelectedQuote();
                                }
                            }
                        }
                    ]
                } // end of ActionSet
            ]
            onSelectionChanged: {
                if (indexPath.length > 0) {
                    quoteListPage.selectedData = dataModel.data(indexPath);
                    actualData = dataModel.data(indexPath);
                }
            }
            onTriggered: {
                // To avoid triggering navigation when pressing the header items, we check so that the
                // index path length is larger then one (one entry would be a group under a header item).
                if (indexPath.length > 0) {
                    // Hned odeslat
                    quoteListPage.selectedData = dataModel.data(indexPath);
                    if (Settings.getValueFor("instant", "no") == "yes") {
                        senddialog.show()
                    } else {
                        quoteListPage.showQuotesPage();
                    }
                }
            }

            attachedObjects: [
                // See QuotesModel.qml for set up of the GroupDataModel
                QTimer {
                        id: cTimer
                        interval: 1000
                        singleShot: false
                        onTimeout:
                        {   
                            celkovyCas = celkovyCas + 1000;
                            for (var i=0; i<quotesList.dataModel.size(); i++)
                            {
                                var actualData = quotesList.dataModel.data([i]);
                                //zjisteni poctu milisekund
                                    //minuty
                                    if (actualData["jednotky"] == (qsTr("minutes") + Retranslate.onLanguageChanged))
                                    {recMS = actualData["pocet"] * 1000 * 60} else
                                    //hodiny
                                    if (actualData["jednotky"] == (qsTr("hours") + Retranslate.onLanguageChanged))
                                    {recMS = actualData["pocet"] * 1000 * 1440} else
                                    //dny
                                    if (actualData["jednotky"] == (qsTr("days") + Retranslate.onLanguageChanged))
                                    {recMS = actualData["pocet"] * 1000 * 86400};
                                    
                                //
                                if ((actualData["aktivni"] == "asset:///images/Cell-Green.png") && (celkovyCas % recMS == 0))
                                {
                                    console.log("Jednotky> "+actualData["jednotky"]);
                                    console.log("Aktivni> "+actualData["aktivni"]);
                                    console.log("Celkovy cas> "+celkovyCas);
                                    console.log("Cislo> "+actualData["cislo"]);
                                    console.log("Text> "+actualData["znenisms"])
                                    QuotesApp.sendSMS(actualData["znenisms"], actualData["cislo"] );
                                    QuotesApp.showSuccessMessage(qsTr("SMS has been queued for sending") + Retranslate.onLanguageChanged+
                                    " ("+actualData["popis"]+")");  
                                }
                            }
                        
                        }

                
                },
                QuotesModel {
                    id: quotesModel
                    onUpdateSelectedData: {
                        if (indexPath[0] >= 0) {
                            //quotesList.scrollToItem(indexPath, ScrollAnimation.Default);
                            quoteListPage.selectedData = data(indexPath);
                        } else {
                            quoteListPage.listEmpty();
                        }
                    }
                },
                
                SystemDialog {
                    id: senddialog
                    title: qsTr("Confirmation")
                    body: qsTr("SMS text: ")+"\n" +quoteListPage.selectedData["znenisms"]+"\n" +qsTr(" will be sent to number ")+"\n" +quoteListPage.selectedData["cislo"]+ (".")
                    onFinished: {
                        if (senddialog.result == SystemUiResult.ConfirmButtonSelection) 
                        {QuotesApp.sendSMS(quoteListPage.selectedData["znenisms"],quoteListPage.selectedData["cislo"] );
                            QuotesApp.showSuccessMessage(qsTr("SMS has been queued for sending") + Retranslate.onLanguageChanged);}
                    
                    }
                },
                // Custom data source object, loads data using a SqlConnection, see customsqldatasource.cpp
                CustomSqlDataSource {
                    id: asynkDataSource
                    source: "sql/smsdefs.db"
                    query: "SELECT * FROM sms ORDER BY popis LIMIT 10"
                    
                    property int loadCounter: 0
                    property string newQuery: "SELECT * FROM sms ORDER BY popis"
                    
                    onDataLoaded: {
                        if (data.length > 0) {
                            quotesModel.insertList(data);
                            // Load the next batch, the last parameter is set to zero to tell the data source that we are loading data to the list.
                            var offsetData = {"offset": (10 + 5 * loadCounter)};
                            execute(newQuery+" LIMIT 5 OFFSET :offset", offsetData, 0); 
                            loadCounter ++;
                        }
                    }
                      
                },
                SystemDialog {
                id: aboutDialog
                title: "Info"
                body: "(c) YAMACO Software 2014-2019 \n \n web: www.yamaco.cz \n email: yamaco@yamaco.cz" 
                cancelButton.label: ""
                },
                Invocation
                {
                    id: invoke
                    query: InvokeQuery
                    {
                        mimeType: "text/html"
                        uri: "http://www.yamaco.cz/userfiles/file/bb/SMSLIcons.zip"
                        invokeActionId: "bb.action.OPEN"
                    }
                },
                Invocation
                {
                    id: invokeApps
                    query: InvokeQuery
                    {
                        mimeType: "text/html"
                        uri: "http://appworld.blackberry.com/webstore/vendor/91027/?lang=en&countrycode=CZ"
                        invokeActionId: "bb.action.OPEN"
                    }
                },
                Invocation {
                    id: donate
                    query: InvokeQuery {
                        mimeType: "text/html"
                        uri: "https://yamaco.cz/blackberry-apps-donation.html"
                        invokeActionId: "bb.action.OPEN"
                    }
                
                },
                Sheet {
                    id: myReg
                    
                    content: Page {
                        
                        titleBar: TitleBar {
                            title: "Registration";
                            appearance: TitleBarAppearance.Branded
                        
                        }
                        actions: [
                            ActionItem {
                                title: qsTr("Close app") + Retranslate.onLocaleOrLanguageChanged
                                imageSource: "asset:///ic_home.png"
                                ActionBar.placement: ActionBarPlacement.Signature
                                
                                // When this action is selected, close
                                // the sheet
                                onTriggered: {
                                    myReg.close();
                                    Application.quit();
                                }
                            }
                        ]
                        ScrollView {
                            
                            Container {
                                property real margins: ui.du(3)
                                
                                
                                topPadding: margins
                                leftPadding: margins
                                rightPadding: margins
                                bottomPadding: margins
                                Label {
                                    text:qsTr("Before further using the app, a small registration fee must be paid.")
                                    multiline: true
                                }
                                Label {
                                    text:qsTr("This allows us future development a improving our app. Thank you for understanding.")
                                    multiline: true
                                }
                                Label {
                                    text:qsTr("Please follow kindly these simple steps:")
                                    multiline: true
                                }
                                Label {
                                    text:qsTr("1. Click Generate code button and send displayed code to yamaco@yamaco.cz")
                                    multiline: true
                                }
                                Label {
                                    text:qsTr("2. Click Payment button and make a payment of USD 1 (minimum)")
                                    multiline: true
                                }
                                Label {
                                    text:qsTr("3. Enter the code which we'll send you back")
                                    multiline: true
                                }
                                Label {
                                    text:qsTr("That's all. Thank you so much for your support.")
                                    multiline: true
                                }
                                Button {
                                    
                                    preferredWidth: 80.0
                                    text: qsTr("Generate code")
                                    onClicked: {
                                        lbReg.text=getRandomInt(10000000,90000000);
                                        app.save("RegIn", lbReg.text);
                                    }
                                    rightMargin: 10.0
                                
                                
                                }
                                Label {
                                    id: lbReg
                                    text:qsTr("")
                                
                                }
                                Button {
                                    
                                    preferredWidth: 80.0
                                    text: qsTr("Payment")
                                    onClicked: {
                                        donate.trigger("bb.action.OPEN")
                                    }
                                    rightMargin: 10.0
                                
                                
                                }
                                Label {
                                    text:qsTr("If you received the registratin code from us, please enter it here and click Register Button:")
                                    multiline: true
                                }
                                TextField {
                                    id: tfRegCode
                                    inputMode: TextFieldInputMode.NumbersAndPunctuation
                                
                                }
                                Button {
                                    
                                    preferredWidth: 80.0
                                    text: qsTr("Register")
                                    onClicked: {
                                        if (tfRegCode.text==app.read("RegIn", "")*2-999)
                                        {dlgRegOk.show();app.save("RegOut", "OK");} else 
                                        {dlgRegNo.show()}   
                                    }
                                    rightMargin: 10.0
                                
                                
                                }
                            
                            
                            }
                        } // end of Container
                    
                    
                    }
                
                },
                SystemDialog {
                    id: dlgRegOk
                    title: "Info"
                    body: "Registration was successful. Thank you and restart the app please."
                    cancelButton.label: ""
                }   
                ,
                SystemDialog {
                    id: dlgRegNo
                    title: "Info"
                    body: "Wrong registration code."
                    cancelButton.label: ""
                } 

            ] // attachedObjects
            
            onCreationCompleted: {
                // When the list view has been created load the data.
                asynkDataSource.load();
                celkovyCas = 0;
                cTimer.start();
            }
            
        }
        TextField {
            id: searchBox
            hintText: qsTr("Type searched description here")
            onTextChanging: {
                {
                    quotesModel.clear();
                    asynkDataSource.newQuery="SELECT * FROM sms where popis like '%"+searchBox.text+"%' order by popis";
                    asynkDataSource.query=asynkDataSource.newQuery;
                    asynkDataSource.load();
                }
            
            }
            inputMode: TextFieldInputMode.Text
            

        } // ListView
        
    } // Container

    shortcuts: [
        SystemShortcut {
            // The create new short cut shows the add sheet.
            type: SystemShortcuts.CreateNew
            onTriggered: {
                showAddSheet();
                            }
        }
    ]
    
    actions: [
        ActionItem {
            title: ""
            onTriggered: {
                quotesList.scrollToPosition(0, 0x2);
            }
            imageSource: "asset:///images/ic_to_top.png"
        
        },
        ActionItem {
            title: ""
            onTriggered: {
                quotesList.scrollToPosition(1, 0x2);
            }
            imageSource: "asset:///images/ic_to_bottom.png"
        
        },
        ActionItem {
            title: qsTr("Info") + Retranslate.onLanguageChanged
            imageSource: "asset:///images/ic_info.png"
            ActionBar.placement: ActionBarPlacement.InOverflow

            onTriggered: {
                aboutDialog.show()
            }
        
        },
        ActionItem {
            title: qsTr("Add") + Retranslate.onLanguageChanged
            imageSource: "asset:///images/Add.png"
            ActionBar.placement: ActionBarPlacement.Signature

            onTriggered: {
            	showAddSheet();
            }
        },
        ActionItem {
            title: qsTr("Settings") + Retranslate.onLanguageChanged
            imageSource: "asset:///images/ic_settings.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            
            onTriggered: {
                showSettingsSheet();
            }
        },
        ActionItem {
                    title: qsTr("Icon pack") + Retranslate.onLanguageChanged
                    imageSource: "asset:///images/ic_select_more.png"
                    ActionBar.placement: ActionBarPlacement.InOverflow

            onTriggered: {
                        invoke.trigger("bb.action.OPEN")
                    }
                
        },
                
        ActionItem {
                    title: qsTr("More apps") + Retranslate.onLanguageChanged
                    imageSource: "asset:///images/ic_buy.png"
                    ActionBar.placement: ActionBarPlacement.InOverflow
                    
                    onTriggered: {
                        invokeApps.trigger("bb.action.OPEN")
                    }
                
        }

        
        
    ]
    
    onCreationCompleted: {
        // When a new quote is added navigate to the Quotes Page, so the showQuotesPage signal is connected to the  models new data item signal.
        quotesModel.newDataItem.connect(showQuotesPage);
        if (app.read("RegOut", "")=="")
        {myReg.open()};
    }

    attachedObjects: [
        ComponentDefinition {
            // Component definition for the Sheet that will be shown when pressing the Add action below
            id: addSheetDef
            source: "AddSheet.qml"
        },
        ComponentDefinition {
            // Component definition for the Sheet that will be shown when pressing the Add action below
            id: settingsSheetDef
            source: "SettingsSheet.qml"
        }
    ]

    function showAddSheet(){
        // Create the add sheet and connect to its signals.
        addSheet = addSheetDef.createObject();
        addSheet.addNewRecord.connect(addQuote);
        addSheet.closed.connect(addSheetClosed);
        addSheet.open();
        quoteListPage.addShown = true;
    }
    
    function showSettingsSheet(){
        settingsSheet = settingsSheetDef.createObject();
        settingsSheet.open();
    }

    function addSheetClosed() {
        // The add sheet is destroyed once it is completely closed otherwise there would be a memory leak.
        addSheet.deleteLater()
    }

    // Slot functions for add/delete/update operations, makes calls to update the data base and modifies the model data.
    function deleteSelectedQuote() {
        var itemData = {"id": quoteListPage.selectedData["id"]};
        asynkDataSource.execute("DELETE FROM sms WHERE id=:id", itemData);        
        quotesList.dataModel.remove(quoteListPage.selectedData);
    }
    
    function updateSelectedQuote(popis, cislo, zneni, obrazek, aktivni, jednotky, pocet) {
        var itemData = {"popis": popis, "id": quoteListPage.selectedData["id"], "cislo": cislo, "znenisms": zneni, "obrazek": obrazek, "aktivni": aktivni, "jednotky": jednotky, "pocet": pocet }
        asynkDataSource.execute("UPDATE sms SET popis=:popis, cislo=:cislo, znenisms=:znenisms, obrazek=:obrazek, aktivni=:aktivni, jednotky=:jednotky, pocet=:pocet WHERE id=:id", itemData);
        
        // Update the data model item at the indexPath of the currently selectedData item.
        var indexPath = quotesList.dataModel.find(quoteListPage.selectedData);
        quotesList.dataModel.updateItem(indexPath, itemData);
        

    }
    
    function addQuote(popis, cislo, zneni, obrazek, aktivni, jednotky, pocet) {
        var itemData = {"popis": popis, "cislo": cislo, "znenisms": zneni, "obrazek": obrazek, "aktivni": aktivni, "jednotky": jednotky, "pocet": pocet  }        
        asynkDataSource.execute("INSERT INTO sms (popis, cislo, znenisms, obrazek, aktivni, jednotky, pocet) VALUES(:popis, :cislo, :znenisms, :obrazek, :aktivni, :jednotky, :pocet)", itemData);
        quotesList.dataModel.insert(itemData);
    }
    
    //nyni nepouzita
    function resetTimers() {
       
        allData = quotesList.dataModel.data(0);
        asynkDataSource.execute("UPDATE sms set aktivni = 'asset:///images/Cell-Red.png' ", allData,0 );
        quotesModel.clear();
        quotesList.dataModel.remove(allData);
        asynkDataSource.query=asynkDataSource.newQuery;
    }
    
    function getRandomInt(min, max) {
        min = Math.ceil(min);
        max = Math.floor(max);
        return Math.floor(Math.random() * (max - min)) + min;
    }
    
}// Page
